Task: WOZ restaurant reservation (Goal-Oriented Dialogue)
==========================================================
Description: Dataset containing dialogues dengotiating a restaurant reservation. Implemented as part of the DecaNLP task, focused on the change in the dialogue state. Original paper: https://arxiv.org/abs/1604.04562

Tags: #woz, #All, #decanlp

